@@ -88,9 +88,9 @@ class LogSniffer():
 		for system in self.systems:
 			if self.log not in system: system[self.log] = False
 		filtered_systems = [x for x in self.systems if x[self.log] is True]
-		info(f"{self.log} found in {len(filtered_systems)} rooms:")
-		for x in filtered_systems:
-			info(f"\t{x['full_name']}")
+		info(f"{self.log} found in {len(filtered_systems)} rooms: {filtered_systems['full_name']}")
+		# for x in filtered_systems:
+		# 	info(f"\t{x['full_name']}")
 
 		tasks = []
 		for i, _ in enumerate(filtered_systems):
